@@ -161,6 +161,9 @@ Note: This field may return `null`, indicating that no valid value can be found.
         :type RegionId: str
         :param ProjectId: Project ID: ID of the project to which the resource belongs
         :type ProjectId: int
+        :param PriceInfo: Price attribute
+Note: This field may return null, indicating that no valid values can be obtained.
+        :type PriceInfo: list of str
         """
         self.BusinessCodeName = None
         self.ProductCodeName = None
@@ -186,6 +189,7 @@ Note: This field may return `null`, indicating that no valid value can be found.
         self.ActionType = None
         self.RegionId = None
         self.ProjectId = None
+        self.PriceInfo = None
 
 
     def _deserialize(self, params):
@@ -223,6 +227,7 @@ Note: This field may return `null`, indicating that no valid value can be found.
         self.ActionType = params.get("ActionType")
         self.RegionId = params.get("RegionId")
         self.ProjectId = params.get("ProjectId")
+        self.PriceInfo = params.get("PriceInfo")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -694,7 +699,7 @@ class CosDetailSets(AbstractModel):
         :type DosageBeginTime: str
         :param DosageEndTime: The end time of the usage
         :type DosageEndTime: str
-        :param SubProductCodeName: Sub-product name
+        :param SubProductCodeName: Subproduct name
         :type SubProductCodeName: str
         :param BillingItemCodeName: Billable item name
         :type BillingItemCodeName: str
@@ -762,7 +767,7 @@ class DescribeAccountBalanceResponse(AbstractModel):
         :type IsAllowArrears: bool
         :param IsCreditLimited: Whether you have a credit limit. Currently, this field is not applied.
         :type IsCreditLimited: bool
-        :param CreditAmount: Credit limit. Credit limit－available credit balance = consumption amount
+        :param CreditAmount: Credit limit in cents. Credit limit－available credit balance = consumption amount
         :type CreditAmount: float
         :param CreditBalance: Available credit balance in cents, which takes the same calculation rules as `Balance`, `RealBalance`, and `RealCreditBalance`.
         :type CreditBalance: float
@@ -819,9 +824,21 @@ class DescribeBillDetailRequest(AbstractModel):
         :type PeriodType: str
         :param Month: Month; format: yyyy-mm. You only have to enter either Month or BeginTime and EndTime. When you enter values for BeginTime and EndTime, Month becomes invalid. This value must be no earlier than the month when Bill 2.0 is activated; last 24 months data are available.
         :type Month: str
-        :param BeginTime: The start time of the period; format: Y-m-d H:i:s. You only have to enter either Month or BeginTime and EndTime. When you enter values for BeginTime and EndTime, Month becomes invalid. BeginTime and EndTime must be inputted as a pair. This value must be no earlier than the month when Bill 2.0 is activated; last 24 months data are available.
+        :param BeginTime: The start time of the query range, which should be in the format Y-m-d H:i:s . The query range must be in the last 18 months and cannot be earlier than May 2018 (when Bill 2.0 was introduced). The start time and end time must be in the same month.
+
+Example: tccli billing DescribeBillDetail --cli-unfold-argument --Offset 1 --Limit 100 --BeginTime '2023-04-01 12:05:15' --EndTime '2023-04-18 12:00:10' --ProjectId 1000000731  --version "2018-07-09"
+
+Alternatively, you can use Month to query the billing details of a month.
+Example:
+ccli billing DescribeBillDetail --cli-unfold-argument --Offset 1 --Limit 100 --Month 2023-04  --version "2018-07-09" --ResourceId "disk-oj9okstm"
         :type BeginTime: str
-        :param EndTime: The end time of the period; format: Y-m-d H:i:s. You only have to enter either Month or BeginTime and EndTime. When you enter values for BeginTime and EndTime, Month becomes invalid. BeginTime and EndTime must be inputted as a pair. This value must be no earlier than the month when Bill 2.0 is activated; last 24 months data are available.
+        :param EndTime: The end time of the query range, which should be in the format `Y-m-d H:i:s `. The query range must be in the last 18 months and cannot be earlier than May 2018 (when Bill 2.0 was introduced). The start time and end time must be in the same month.
+
+Example: tccli billing DescribeBillDetail --cli-unfold-argument --Offset 1 --Limit 100 --BeginTime '2023-04-01 12:05:15' --EndTime '2023-04-18 12:00:10' --ProjectId 1000000731  --version "2018-07-09"
+
+Alternatively, you can use `Month` to query the billing details of a month. 
+Example:
+ccli billing DescribeBillDetail --cli-unfold-argument --Offset 1 --Limit 100 --Month 2023-04  --version "2018-07-09" --ResourceId "disk-oj9okstm"
         :type EndTime: str
         :param NeedRecordNum: Indicates whether or not the total number of records of accessing the list is required, used for frontend pages.
 1 = yes, 0 = no
@@ -1316,7 +1333,7 @@ class DescribeBillSummaryByTagRequest(AbstractModel):
         :type BeginTime: str
         :param EndTime: The value must be of the same month as `BeginTime`. Query period must start and end on the same month and the query result returned will be of the entire month. For example, if both `BeginTime` and `EndTime` are `2018-09`, the data returned will be for the entire month of September 2018.
         :type EndTime: str
-        :param TagKey: Cost allocation tag key
+        :param TagKey: Cost allocation tag key, which can be customized.
         :type TagKey: str
         :param PayerUin: Payer UIN
         :type PayerUin: str
@@ -1390,9 +1407,9 @@ class DescribeDosageCosDetailByDateRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param StartDate: The start date of the usage query
+        :param StartDate: The start date of the usage query, such as `2020-09-01`.
         :type StartDate: str
-        :param EndDate: The end date of the usage query (end date must be in the same month as the start date)
+        :param EndDate: The end date of the usage query (end date must be in the same month as the start date), such as `2020-09-30`.
         :type EndDate: str
         :param BucketName: Bucket name. You can use `Get Service` to query the list of all buckets under a requester account. For details, see [GET Service (List Buckets)](https://www.tencentcloud.com/document/product/436/8291).
         :type BucketName: str
@@ -1464,9 +1481,9 @@ class DescribeVoucherInfoRequest(AbstractModel):
         :type ActivityId: str
         :param VoucherName: The voucher name.
         :type VoucherName: str
-        :param TimeFrom: The start time of the promotional campaign.
+        :param TimeFrom: The start date of the voucher issuance, such as `2021-01-01`.
         :type TimeFrom: str
-        :param TimeTo: The end time of the promotional campaign.
+        :param TimeTo: The end date of the voucher issuance, such as `2021-01-01`.
         :type TimeTo: str
         :param SortField: The field used to sort the records. Valid values: BeginTime, EndTime, CreateTime.
         :type SortField: str
