@@ -17,6 +17,9 @@
 # CAM signature/authentication error.
 AUTHFAILURE = 'AuthFailure'
 
+# Invalid authorization
+AUTHFAILURE_INVALIDAUTHORIZATION = 'AuthFailure.InvalidAuthorization'
+
 # The sub-account has no permissions.
 AUTHFAILURE_SUBACCOUNTDENIED = 'AuthFailure.SubAccountDenied'
 
@@ -71,6 +74,9 @@ FAILEDOPERATION_JSONUNMARSHALERROR = 'FailedOperation.JsonUnmarshalError'
 # It is not a read-only instance with delayed replication enabled.
 FAILEDOPERATION_NOTDELAYRO = 'FailedOperation.NotDelayRo'
 
+# The instance has an operation in progress. Try again later.
+FAILEDOPERATION_OPERATIONINCONFLICTERR = 'FailedOperation.OperationInConflictErr'
+
 # The executed operation to modify permissions is invalid. You can refer to product documentation for more information about permissions that can be modified for this instance. If you have any questions, please contact customer service.
 FAILEDOPERATION_PRIVILEGEDATAILLEGAL = 'FailedOperation.PrivilegeDataIllegal'
 
@@ -179,6 +185,9 @@ INTERNALERROR_INTERNALSERVICEERRORERR = 'InternalError.InternalServiceErrorErr'
 # Failed to parse JSON.
 INTERNALERROR_JSONERROR = 'InternalError.JSONError'
 
+# Failed to enable encryption
+INTERNALERROR_KMSERROR = 'InternalError.KmsError'
+
 # Network error
 INTERNALERROR_NETWORKERROR = 'InternalError.NetworkError'
 
@@ -275,6 +284,9 @@ INVALIDPARAMETER_RESOURCENOTEXISTS = 'InvalidParameter.ResourceNotExists'
 # The resource is not found.
 INVALIDPARAMETER_RESOURCENOTFOUND = 'InvalidParameter.ResourceNotFound'
 
+# Invalid parameter value
+INVALIDPARAMETERVALUE = 'InvalidParameterValue'
+
 # The account description contains special characters.
 INVALIDPARAMETERVALUE_ACCOUNTDESCRIPTIONCHARACTERERROR = 'InvalidParameterValue.AccountDescriptionCharacterError'
 
@@ -329,6 +341,9 @@ MISSINGPARAMETER_MISSINGPARAMERROR = 'MissingParameter.MissingParamError'
 # Operation denied.
 OPERATIONDENIED = 'OperationDenied'
 
+# The Tencent Cloud account is not allowed to perform the operation due to insufficient permissions.
+OPERATIONDENIED_ACCOUNTOPERATIONDENIED = 'OperationDenied.AccountOperationDenied'
+
 # The instance is performing another task.
 OPERATIONDENIED_ACTIONINPROCESS = 'OperationDenied.ActionInProcess'
 
