@@ -509,6 +509,40 @@ class ClbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeregisterFunctionTargets(self, request):
+        """This API is used to unbind a SCF function with a CLB forwarding rule. For L7 listeners, you need to specify the forwarding rule by using `LocationId` or `Domain+Url`.
+        This is an async API. After it is returned successfully, you can call the [DescribeTaskStatus](https://intl.cloud.tencent.com/document/product/214/30683?from_cn_redirect=1) API with the returned RequestID to check whether this task is successful.
+        <br/>Limits:
+
+        - Binding with SCF is only available in Guangzhou, Shenzhen Finance, Shanghai, Shanghai Finance, Beijing, Chengdu, Hong Kong (China), Singapore, Mumbai, Tokyo, and Silicon Valley.
+        - SCF functions can only be bound with CLB instances of bill-by-IP accounts but not with bill-by-CVM accounts. If you are using a bill-by-CVM account, we recommend upgrading it to a bill-by-IP account. For more information, please see [Checking Account Type](https://intl.cloud.tencent.com/document/product/1199/49090?from_cn_redirect=1).
+        - SCF functions cannot be bound with classic CLB instances.
+        - SCF functions cannot be bound with classic network-based CLB instances.
+        - SCF functions in the same region can be bound with CLB instances. SCF functions can only be bound across VPCs but not regions.
+        - SCF functions can only be bound with IPv4 and IPv6 NAT64 CLB instances, but currently not with IPv6 CLB instances.
+        - SCF functions can only be bound with layer-7 HTTP and HTTPS listeners, but not with layer-7 QUIC listeners or layer-4 (TCP, UDP, and TCP SSL) listeners.
+        - Only SCF event-triggered functions can be bound with CLB instances.
+
+        :param request: Request instance for DeregisterFunctionTargets.
+        :type request: :class:`tencentcloud.clb.v20180317.models.DeregisterFunctionTargetsRequest`
+        :rtype: :class:`tencentcloud.clb.v20180317.models.DeregisterFunctionTargetsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeregisterFunctionTargets", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeregisterFunctionTargetsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeregisterTargetGroupInstances(self, request):
         """This API is used to unbind a server from a target group.
         This is an async API. After it is returned successfully, you can call the API `DescribeTaskStatus` with the returned RequestId as an input parameter to check whether this task is successful.
@@ -1344,6 +1378,29 @@ class ClbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyFunctionTargets(self, request):
+        """This API is used to modify the cloud functions associated with a load balancing forwarding rule.
+
+        :param request: Request instance for ModifyFunctionTargets.
+        :type request: :class:`tencentcloud.clb.v20180317.models.ModifyFunctionTargetsRequest`
+        :rtype: :class:`tencentcloud.clb.v20180317.models.ModifyFunctionTargetsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyFunctionTargets", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyFunctionTargetsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyListener(self, request):
         """This API (ModifyListener) is used to modify the attributes of a CLB listener, such as listener name, health check parameter, certificate information, and forwarding policy.
         This is an async API. After it is returned successfully, you can call the DescribeTaskStatus API with the returned RequestID as an input parameter to check whether this task is successful.
@@ -1393,7 +1450,12 @@ class ClbClient(AbstractClient):
 
 
     def ModifyLoadBalancerSla(self, request):
-        """This API is used to upgrade shared CLB instances to LCU-supported CLB instances.
+        """This API is used to upgrade a pay-as-you-go shared CLB instance to an LCU-supported CLB instance.<br/>
+        Limits
+        - This API can be used to upgrade only a pay-as-you-go shared instance. A monthly subscription shared instance must be upgraded in the console.
+        - An LCU-supported instance cannot be rolled back to a shared instance.
+        - LCU-supported instances are in beta testing. To upgrade to an LCU-supported instance, [submit a ticket](https://intl.cloud.tencent.com/apply/p/hf45esx99lf?from_cn_redirect=1) for application.
+        - Classic CLB instances cannot be upgraded to LCU-supported instances.
 
         :param request: Request instance for ModifyLoadBalancerSla.
         :type request: :class:`tencentcloud.clb.v20180317.models.ModifyLoadBalancerSlaRequest`
@@ -1558,6 +1620,39 @@ class ClbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def RegisterFunctionTargets(self, request):
+        """This API is used to bind an SCF function with the L7 forwarding rule of a CLB instance. Note that you need to create an L7 listener (HTTP, HTTPS) and forwarding rule first.
+        This is an async API. After it is returned successfully, you can call the `DescribeTaskStatus` API with the returned `RequestID` as an input parameter to check whether this task is successful.<br/>
+        **Limits:**
+        - Binding with SCF is only available in Guangzhou, Shenzhen Finance, Shanghai, Shanghai Finance, Beijing, Chengdu, Hong Kong (China), Singapore, Mumbai, Tokyo, and Silicon Valley.
+        - SCF functions can only be bound with CLB instances of bill-by-IP accounts but not with bill-by-CVM accounts. If you are using a bill-by-CVM account, we recommend upgrading it to a bill-by-IP account. For more information, please see [Checking Account Type](https://intl.cloud.tencent.com/document/product/1199/49090?from_cn_redirect=1).
+        - SCF functions cannot be bound with classic CLB instances.
+        - SCF functions cannot be bound with classic network-based CLB instances.
+        - SCF functions in the same region can be bound with CLB instances. SCF functions can only be bound across VPCs but not regions.
+        - SCF functions can only be bound with IPv4 and IPv6 NAT64 CLB instances, but currently not with IPv6 CLB instances.
+        - SCF functions can only be bound with layer-7 HTTP and HTTPS listeners, but not with layer-7 QUIC listeners or layer-4 (TCP, UDP, and TCP SSL) listeners.
+        - Only SCF event-triggered functions can be bound with CLB instances.
+
+        :param request: Request instance for RegisterFunctionTargets.
+        :type request: :class:`tencentcloud.clb.v20180317.models.RegisterFunctionTargetsRequest`
+        :rtype: :class:`tencentcloud.clb.v20180317.models.RegisterFunctionTargetsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RegisterFunctionTargets", params, headers=headers)
+            response = json.loads(body)
+            model = models.RegisterFunctionTargetsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def RegisterTargetGroupInstances(self, request):
         """This API is used to register servers to a target group.
         This is an async API. After it is returned successfully, you can call the `DescribeTaskStatus` API with the returned `RequestID` as an input parameter to check whether this task is successful.
