@@ -14,16 +14,16 @@
 # limitations under the License.
 
 
-# CAM signature/authentication error
+# Error with CAM signature/authentication.
 AUTHFAILURE = 'AuthFailure'
 
 # Operation failed.
 FAILEDOPERATION = 'FailedOperation'
 
-# An internal error occurred.
+# Internal error.
 INTERNALERROR = 'InternalError'
 
-# Invalid parameter.
+# Incorrect parameter.
 INVALIDPARAMETER = 'InvalidParameter'
 
 # Incorrect parameter value.
@@ -32,20 +32,23 @@ INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 # Missing parameter.
 MISSINGPARAMETER = 'MissingParameter'
 
-# Operation denied
+# Operation denied.
 OPERATIONDENIED = 'OperationDenied'
 
-# CAM authentication error
+# Error with CAM authentication.
 OPERATIONDENIED_USERHASNOSTRATEGY = 'OperationDenied.UserHasNoStrategy'
 
-# Request exceeded the frequency limit
+# The number of requests exceeds the frequency limit.
 REQUESTLIMITEXCEEDED = 'RequestLimitExceeded'
 
-# Unauthorized operation.
+# The resource does not exist.
+RESOURCENOTFOUND = 'ResourceNotFound'
+
+# The operation is unauthorized.
 UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 
 # Unknown parameter.
 UNKNOWNPARAMETER = 'UnknownParameter'
 
-# Unsupported operation
+# Unsupported operation.
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
