@@ -169,6 +169,29 @@ class LcicClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def BatchDescribeDocument(self, request):
+        """This API is used to get courseware information.
+
+        :param request: Request instance for BatchDescribeDocument.
+        :type request: :class:`tencentcloud.lcic.v20220817.models.BatchDescribeDocumentRequest`
+        :rtype: :class:`tencentcloud.lcic.v20220817.models.BatchDescribeDocumentResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("BatchDescribeDocument", params, headers=headers)
+            response = json.loads(body)
+            model = models.BatchDescribeDocumentResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def BatchRegister(self, request):
         """This API is used to register multiple users (up to 1,000) at a time. If a user ID already exists, the existing one will be overwritten.
         A maximum of 20 requests can be initiated per second for this API.
@@ -476,6 +499,52 @@ class LcicClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteSupervisor(self, request):
+        """This API is used to delete spectators.
+
+        :param request: Request instance for DeleteSupervisor.
+        :type request: :class:`tencentcloud.lcic.v20220817.models.DeleteSupervisorRequest`
+        :rtype: :class:`tencentcloud.lcic.v20220817.models.DeleteSupervisorResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteSupervisor", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteSupervisorResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeAnswerList(self, request):
+        """This API is used to get the answers to a quiz question in a room.
+
+        :param request: Request instance for DescribeAnswerList.
+        :type request: :class:`tencentcloud.lcic.v20220817.models.DescribeAnswerListRequest`
+        :rtype: :class:`tencentcloud.lcic.v20220817.models.DescribeAnswerListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAnswerList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAnswerListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeCurrentMemberList(self, request):
         """This API is used to get the user list of a room. This API will not work if a room has ended or expired.
         A maximum of 20 requests can be initiated per second for this API.
@@ -547,6 +616,33 @@ class LcicClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeDocuments(self, request):
+        """有新接口替换
+
+        A new API is offered for this action now.
+
+        This API is used to query courseware. It has been deprecated. Please use `BatchDescribeDocument` instead.
+
+        :param request: Request instance for DescribeDocuments.
+        :type request: :class:`tencentcloud.lcic.v20220817.models.DescribeDocumentsRequest`
+        :rtype: :class:`tencentcloud.lcic.v20220817.models.DescribeDocumentsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDocuments", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeDocumentsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeDocumentsByRoom(self, request):
         """This API is used to get the document list of a specific room.
         A maximum of 20 requests can be initiated per second for this API.
@@ -643,6 +739,29 @@ class LcicClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeQuestionList(self, request):
+        """This API is used to get the quiz details of a room.
+
+        :param request: Request instance for DescribeQuestionList.
+        :type request: :class:`tencentcloud.lcic.v20220817.models.DescribeQuestionListRequest`
+        :rtype: :class:`tencentcloud.lcic.v20220817.models.DescribeQuestionListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeQuestionList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeQuestionListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeRoom(self, request):
         """This API is used to get room information.
         A maximum of 20 requests can be initiated per second for this API.
@@ -715,6 +834,29 @@ class LcicClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeSupervisors(self, request):
+        """This API is used to get the spectators of a room.
+
+        :param request: Request instance for DescribeSupervisors.
+        :type request: :class:`tencentcloud.lcic.v20220817.models.DescribeSupervisorsRequest`
+        :rtype: :class:`tencentcloud.lcic.v20220817.models.DescribeSupervisorsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeSupervisors", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeSupervisorsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeUser(self, request):
         """This API is used to obtain user profile.
 
@@ -738,6 +880,29 @@ class LcicClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def EndRoom(self, request):
+        """This API is used to end a room.
+
+        :param request: Request instance for EndRoom.
+        :type request: :class:`tencentcloud.lcic.v20220817.models.EndRoomRequest`
+        :rtype: :class:`tencentcloud.lcic.v20220817.models.EndRoomResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("EndRoom", params, headers=headers)
+            response = json.loads(body)
+            model = models.EndRoomResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def GetRoomEvent(self, request):
         """This API is used to get the events of a room. It only works within one hour after a class ends.
 
@@ -784,6 +949,29 @@ class LcicClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def GetRooms(self, request):
+        """This API is used to get the room list.
+
+        :param request: Request instance for GetRooms.
+        :type request: :class:`tencentcloud.lcic.v20220817.models.GetRoomsRequest`
+        :rtype: :class:`tencentcloud.lcic.v20220817.models.GetRoomsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("GetRooms", params, headers=headers)
+            response = json.loads(body)
+            model = models.GetRoomsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def GetWatermark(self, request):
         """This API is used to get watermark settings.
         A maximum of 20 requests can be initiated per second for this API.
@@ -1020,6 +1208,29 @@ class LcicClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def StartRoom(self, request):
+        """This API is used to start a room. Before you call this API, make sure a user has entered the room so that the class is initialized.
+
+        :param request: Request instance for StartRoom.
+        :type request: :class:`tencentcloud.lcic.v20220817.models.StartRoomRequest`
+        :rtype: :class:`tencentcloud.lcic.v20220817.models.StartRoomResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("StartRoom", params, headers=headers)
+            response = json.loads(body)
+            model = models.StartRoomResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def UnbindDocumentFromRoom(self, request):
         """This API is used to unbind a document from a room.
 
