@@ -969,6 +969,29 @@ class ScfClient(AbstractClient):
             model = models.UpdateNamespaceResponse()
             model._deserialize(response["Response"])
             return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def UpdateTriggerStatus(self, request):
+        """This API is used to update the trigger status.
+
+        :param request: Request instance for UpdateTriggerStatus.
+        :type request: :class:`tencentcloud.scf.v20180416.models.UpdateTriggerStatusRequest`
+        :rtype: :class:`tencentcloud.scf.v20180416.models.UpdateTriggerStatusResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UpdateTriggerStatus", params, headers=headers)
+            response = json.loads(body)
+            model = models.UpdateTriggerStatusResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
